@@ -108,7 +108,7 @@ def add_images_to_existing_project(session, projnumber):
                 ext_artist = select_artist(project_team, users, "Select EXT artist")
             else:
                 ext_artist = project_team[0]
-            if exterior_shots is None and num_existing_ext == 0:
+            if num_existing_ext == 0:
                 print(
                     f"{existing_project['name']} has no EXT images, let's create a folder for them!")
             ext_folder = session.create(
@@ -145,7 +145,7 @@ def add_images_to_existing_project(session, projnumber):
                     project_team, users, "Select MovingImage artist")
             else:
                 moving_artist = project_team[0]
-            if moving_images is None and num_existing_moving == 0:
+            if num_existing_moving == 0:
                 print(
                     f"{existing_project['name']} has no moving images, let's create a folder for them!")
                 moving_folder = session.create(
